#include "unixodbc.h"
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "example.h"


static SQLHDBC dbc;
static SQLHENV env;


static BOOL isConnected = FALSE;

BOOL sql_success(SQLRETURN *rc) 
{
	if(*rc == SQL_SUCCESS || *rc == SQL_SUCCESS_WITH_INFO)
		return TRUE;
	else
		return FALSE;
}

void sql_connect()
{
	SQLRETURN rc;
	
	if(isConnected == TRUE) return;
	
	rc = SQLAllocHandle (SQL_HANDLE_ENV, SQL_NULL_HANDLE, &env);
	
	if(sql_success( &rc ) == TRUE) {
		// env allocated
		
		rc = SQLSetEnvAttr( env, SQL_ATTR_ODBC_VERSION, (void*)SQL_OV_ODBC3, 0);
		rc = SQLAllocHandle( SQL_HANDLE_DBC, env, &dbc);
		
		if(sql_success( &rc ) == TRUE) {
			// dbc allocated
			
			rc = SQLConnect(dbc, (SQLCHAR*)"demo", SQL_NTS, (SQLCHAR*)"dba", SQL_NTS, (SQLCHAR*)"sql", SQL_NTS);
			
			if(sql_success( &rc ) == TRUE) {
				isConnected = TRUE;
			}
		}
	}
}

BOOL sql_check_connection()
{
	return isConnected;
}

void sql_disconnect()
{
	if(isConnected == FALSE) return;
	
	SQLDisconnect(dbc);
	SQLFreeHandle(SQL_HANDLE_DBC,dbc);
	SQLFreeHandle(SQL_HANDLE_ENV,env);
	
	isConnected = FALSE;
}

int get_db_property(SQLCHAR* statement)
{
	SQLRETURN rc;
	SQLHSTMT stmt;
	
	SQLINTEGER cbValue = 0;
	SQLINTEGER value;
	
	if( isConnected == FALSE ) return -1;
	
	SQLAllocHandle( SQL_HANDLE_STMT, dbc, &stmt );
	
	SQLBindCol( stmt, 1, SQL_C_ULONG, &value, 0, &cbValue );
	
	SQLExecDirect( stmt, statement, SQL_NTS);
	
	rc = SQLFetch(stmt);
	
	SQLFreeHandle( SQL_HANDLE_STMT, stmt );
	
	return value;
}

int sql_get_connection_count()
{
	int connCount = get_db_property( (SQLCHAR*)"SELECT DB_PROPERTY('ConnCount')");
	
	return connCount;
}

int sql_get_cache_reads()
{
	int cacheReads = get_db_property((SQLCHAR*) "SELECT DB_PROPERTY('CacheRead')");
	
	return cacheReads;
}

int sql_get_cache_hits()
{
	int cacheHits = get_db_property((SQLCHAR*) "SELECT DB_PROPERTY('CacheHits')");
	
	return cacheHits;
}

int sql_get_cpu_usage()
{
	int cpu = get_db_property((SQLCHAR*) "SELECT PROPERTY('ProcessCPU')*100");
	return cpu;
}

int sql_get_packets_received()
{
	int received = get_db_property((SQLCHAR*) "SELECT PROPERTY('PacketsReceived')");
	return received;
}

int sql_get_packets_sent()
{
	int sent = get_db_property((SQLCHAR*) "SELECT PROPERTY('PacketsSent')");
	return sent;
}

